Crate axum_routes_macros

Crate axum_routes_macros 

Macros

router
Create the axum::Router instance. The first parameter of the macro must be the path to a type that was created from the routes macro.

Attribute Macros

routes
The main macro to create an axum::Router from an enum.