Macros
- router
- Create the
axum::Routerinstance. The first parameter of the macro must be the path to a type that was created from theroutesmacro.
Attribute Macros
- routes
- The main macro to create an
axum::Routerfrom an enum.
axum::Router instance.
The first parameter of the macro must be the path to a type that was created
from the routes macro.axum::Router
from an enum.